import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import * as Parse from 'parse';

@Component({
  selector: 'app-home',
  templateUrl: 'home.page.html',
  styleUrls: ['home.page.scss']
})
export class HomePage implements OnInit {

  items: any[] = [];
  newPostId: string = '';

  constructor(private router: Router, private route: ActivatedRoute) {
    // 初始化 Parse
  }

  ngOnInit() {
    this.route.queryParams.subscribe(params => {
      if (params["postId"]) {
        this.newPostId = params["postId"];
      }
    });
    // this.fetchPosts();
  }

  ionViewWillEnter() {
    this.fetchPosts(); // 确保每次进入首页时都会加载最新的帖子
  }

  async fetchPosts() {
    const Post = Parse.Object.extend("Post240709");
    const query = new Parse.Query(Post);

    try {
      const results = await query.find();
      this.items = results.map(post => ({
        id: post.id,
        title: post.get('title'),
        author: post.get('author'),
        image: post.get('image'),
        description: post.get('description'),
        footer: `${post.get('likes')} 赞同 · ${post.get('comments')} 评论`
      }));
      if (this.newPostId) {
        const newPost = this.items.find(post => post.id === this.newPostId);
        if (newPost) {
          // 可以在这里高亮新发布的帖子或者滚动到新发布的帖子位置
          console.log('New post published:', newPost);
        }
        this.newPostId = ''; // 重置 newPostId
      }
    } catch (error) {
      console.error("Error while fetching posts", error);
    }
  }

  goToPostDetail(id: string) {
    this.router.navigate(['/post-detail', id]);
  }

  createPost() {
    this.router.navigate(['/post-create']);
  }
  
}
